Title: GIOError
SPDX-License-Identifier: LGPL-2.1-or-later
SPDX-FileCopyrightText: 2007 A. Walton

# GIOError

Contains helper functions for reporting errors to the user.

Functions for converting between different error reporting mechanisms:
 * [func@Gio.io_error_from_errno]
 * [func@Gio.io_error_from_file_error]

